View source: R/git_add_and_push_all.R
| git_add_and_push_all | R Documentation |
Para uso interactivo. Hace add a todos los archivos nuevos y modificados, luego les aplica un commit y les hace push. Es una versión menos segura que gert::git_commit_all().
git_add_and_push_all(message = NULL, author = NULL)
message |
Mensaje del commit |
author |
Autor del commit |
Un valor SHA
#git_add_and_push_all("first")
#git_add_and_push_all("update", author = "Otro autor")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.